@@ -38,7 +38,7 @@ class TodoDirective(SphinxDirective):
 
         todo_node = todo('\n'.join(self.content))
         todo_node += nodes.title(_('Todo'), _('Todo'))
-        self.state.nested_parse(self.content, self.content_offset, todo_node)
+        todo_node += self.parse_content_to_nodes()
 
         if not hasattr(self.env, 'todo_all_todos'):
             self.env.todo_all_todos = []
@@ -132,6 +132,7 @@ def setup(app: Sphinx) -> ExtensionMetadata:
 
     return {
         'version': '0.1',
+        'env_version': 1,
         'parallel_read_safe': True,
         'parallel_write_safe': True,
     }
