@@ -1,3 +1,5 @@
 project = 'versioning test root'
-source_suffix = '.txt'
+source_suffix = {
+    '.txt': 'restructuredtext'
+}
 exclude_patterns = ['_build']
