@@ -7,7 +7,7 @@ import pytest
 def test_ext_imgmockconverter(app, status, warning):
     app.build(force_all=True)
 
-    content = (app.outdir / 'python.tex').read_text(encoding='utf8')
+    content = (app.outdir / 'projectnamenotset.tex').read_text(encoding='utf8')
 
     # check identical basenames give distinct files
     assert '\\sphinxincludegraphics{{svgimg}.pdf}' in content
