@@ -21,7 +21,7 @@ from sphinx.writers.html import HTML5Translator, HTMLWriter
 from sphinx.writers.latex import LaTeXTranslator, LaTeXWriter
 
 
-@pytest.fixture()
+@pytest.fixture
 def settings(app):
     texescape.init()  # otherwise done by the latex builder
     with warnings.catch_warnings():
@@ -42,7 +42,7 @@ def settings(app):
     domain_context.disable()
 
 
-@pytest.fixture()
+@pytest.fixture
 def new_document(settings):
     def create():
         document = utils.new_document('test data', settings)
@@ -52,14 +52,14 @@ def new_document(settings):
     return create
 
 
-@pytest.fixture()
+@pytest.fixture
 def inliner(new_document):
     document = new_document()
     document.reporter.get_source_and_line = lambda line=1: ('dummy.rst', line)
     return SimpleNamespace(document=document, reporter=document.reporter)
 
 
-@pytest.fixture()
+@pytest.fixture
 def parse(new_document):
     def parse_(rst):
         document = new_document()
@@ -90,7 +90,7 @@ class ForgivingLaTeXTranslator(LaTeXTranslator, ForgivingTranslator):
     pass
 
 
-@pytest.fixture()
+@pytest.fixture
 def verify_re_html(app, parse):
     def verify(rst, html_expected):
         document = parse(rst)
@@ -102,7 +102,7 @@ def verify_re_html(app, parse):
     return verify
 
 
-@pytest.fixture()
+@pytest.fixture
 def verify_re_latex(app, parse):
     def verify(rst, latex_expected):
         document = parse(rst)
@@ -117,7 +117,7 @@ def verify_re_latex(app, parse):
     return verify
 
 
-@pytest.fixture()
+@pytest.fixture
 def verify_re(verify_re_html, verify_re_latex):
     def verify_re_(rst, html_expected, latex_expected):
         if html_expected:
@@ -127,7 +127,7 @@ def verify_re(verify_re_html, verify_re_latex):
     return verify_re_
 
 
-@pytest.fixture()
+@pytest.fixture
 def verify(verify_re_html, verify_re_latex):
     def verify_(rst, html_expected, latex_expected):
         if html_expected:
@@ -137,7 +137,7 @@ def verify(verify_re_html, verify_re_latex):
     return verify_
 
 
-@pytest.fixture()
+@pytest.fixture
 def get_verifier(verify, verify_re):
     v = {
         'verify': verify,
